# OV_assets.py

import bpy
from bpy.props import PointerProperty, EnumProperty

# Import du property group depuis OV_assets_addasset
from .OV_assets_addasset import OV_AssetsProperties
# Import des fonctions de gestion des previews depuis OV_assets_library
from .OV_assets_library import update_asset_library_enum, update_assetlib, load_previews, unload_previews

# Import des sous-modules pour l'enregistrement
from . import OV_assets_library
from . import OV_assets_addasset
from . import OV_assets_transform

def get_assetlib_selected(self):
    return self.get("_ov_assetlib_selected", "NONE")

def set_assetlib_selected(self, value):
    self["_ov_assetlib_selected"] = value

def register():
    # Enregistrement des sous-modules
    OV_assets_library.register()
    OV_assets_addasset.register()
    OV_assets_transform.register()
    
    # Ajout des propriétés à bpy.types.Scene
    bpy.types.Scene.ov_asset_props = PointerProperty(type=OV_AssetsProperties)
    bpy.types.Scene.ov_assetlib_selected = EnumProperty(
        name="Asset Library",
        description="Select an asset from the library",
        items=update_asset_library_enum,
        get=get_assetlib_selected,
        set=set_assetlib_selected,
        update=update_assetlib
    )
    load_previews()
    print("OV Assets addon registered.")

def unregister():
    unload_previews()
    del bpy.types.Scene.ov_assetlib_selected
    del bpy.types.Scene.ov_asset_props
    OV_assets_addasset.unregister()
    OV_assets_library.unregister()
    OV_assets_transform.unregister()
    print("OV Assets addon unregistered.")

if __name__ == "__main__":
    register()
