# OV_materials.py

import bpy
from bpy.props import PointerProperty, EnumProperty

# Import du property group depuis OV_materials_addmaterial
from .OV_materials_addmaterial import OV_MaterialsProperties
# Import des fonctions de gestion des previews depuis OV_materials_library
from .OV_materials_library import update_material_library_enum, update_matlib, load_previews, unload_previews

# Import des sous-modules pour l'enregistrement
from . import OV_materials_library
from . import OV_materials_addmaterial
from . import OV_materials_transform

def get_matlib_selected(self):
    return self.get("_ov_matlib_selected", "NONE")

def set_matlib_selected(self, value):
    self["_ov_matlib_selected"] = value

def register():
    # Enregistrement des sous-modules
    OV_materials_library.register()
    OV_materials_addmaterial.register()
    OV_materials_transform.register()
    
    # Ajout des propriétés à bpy.types.Scene
    bpy.types.Scene.ov_material_props = PointerProperty(type=OV_MaterialsProperties)
    bpy.types.Scene.ov_matlib_selected = EnumProperty(
        name="Material Library",
        description="Select a material from the library",
        items=update_material_library_enum,
        get=get_matlib_selected,
        set=set_matlib_selected,
        update=update_matlib
    )
    load_previews()
    print("OV Materials addon registered.")

def unregister():
    unload_previews()
    del bpy.types.Scene.ov_matlib_selected
    del bpy.types.Scene.ov_material_props
    OV_materials_addmaterial.unregister()
    OV_materials_library.unregister()
    OV_materials_transform.unregister()
    print("OV Materials addon unregistered.")

if __name__ == "__main__":
    register()
