# OV_setup_start.py

import bpy
import platform
import math

def setup_blender():
    # Définir le moteur de rendu et le périphérique
    bpy.context.scene.render.engine = 'CYCLES'
    bpy.context.scene.cycles.device = 'GPU'
    bpy.context.preferences.inputs.use_emulate_numpad = True

    # Paramètres de Cycles
    bpy.context.scene.cycles.use_adaptive_sampling = False
    bpy.context.scene.cycles.preview_samples = 20
    bpy.context.scene.cycles.samples = 150  # Passage de 200 à 150
    bpy.context.scene.cycles.use_preview_denoising = True
    bpy.context.scene.cycles.preview_denoising_start_sample = 20
    bpy.context.scene.cycles.use_denoising = True

    system = platform.system()
    preferences = bpy.context.preferences
    cycles_prefs = preferences.addons["cycles"].preferences

    if system == "Darwin":
        cycles_prefs.compute_device_type = "METAL"
        print("Render device configured: Metal")
    elif system == "Windows":
        devices = cycles_prefs.get_devices()
        if devices is not None:
            device_types = [device.type for device in devices]
            if "OPTIX" in device_types:
                cycles_prefs.compute_device_type = "OPTIX"
                print("Render device configured: OptiX")
            else:
                cycles_prefs.compute_device_type = "CUDA"
                print("Render device configured: CUDA")
        else:
            cycles_prefs.compute_device_type = "CUDA"
            print("Unable to retrieve devices, default configuration: CUDA")
    else:
        print("No specific render device configured for this system.")

    print("OpenVision configuration completed.")

def clean_all_objects():
    # Supprimer tous les objets de la scène
    bpy.ops.object.select_all(action='SELECT')
    bpy.ops.object.delete()
    print("All objects have been deleted.")

# Operators et Panel pour le module Start

class OV_SETUP_OT_SetupOperator(bpy.types.Operator):
    bl_idname = "ov_setup.setup_operator"
    bl_label = "Setup Blender"
    bl_description = "Configure Blender and enable 'Emulate Numpad'"
    def execute(self, context):
        setup_blender()
        self.report({'INFO'}, "Blender setup completed.")
        return {'FINISHED'}

class OV_SETUP_OT_CleanAll(bpy.types.Operator):
    bl_idname = "ov_setup.clean_all"
    bl_label = "Clean All"
    bl_description = "Delete all objects from the scene"
    def execute(self, context):
        clean_all_objects()
        self.report({'INFO'}, "All objects deleted.")
        return {'FINISHED'}

class OV_SETUP_PT_StartPanel(bpy.types.Panel):
    bl_idname = "OV_SETUP_PT_StartPanel"
    bl_label = "Start"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = 'OpenVision'
    def draw(self, context):
        layout = self.layout
        box = layout.box()
        box.operator("ov_setup.setup_operator", text="Setup Blender")
        box.operator("ov_setup.clean_all", text="Clean All")

def register():
    bpy.utils.register_class(OV_SETUP_OT_SetupOperator)
    bpy.utils.register_class(OV_SETUP_OT_CleanAll)
    bpy.utils.register_class(OV_SETUP_PT_StartPanel)

def unregister():
    bpy.utils.unregister_class(OV_SETUP_PT_StartPanel)
    bpy.utils.unregister_class(OV_SETUP_OT_CleanAll)
    bpy.utils.unregister_class(OV_SETUP_OT_SetupOperator)
